import locale from 'ant-design-vue/es/locale-provider'
import { defineStore } from 'pinia'



export interface ISystemState {
  locale: string;
  localeList: ILocale[];
}


export interface ILocale {
  name: string;
  value: string;
}




const useSystemStore = defineStore('system', {
  state: (): ISystemState => ({
    locale: !!localStorage.getItem('locale') && localStorage.getItem('locale') !== 'null' && localStorage.getItem('locale') !== 'undefine' ? (localStorage.getItem('locale') as string) : 'zhCN',
    localeList: [
      { name: '简体中文', value: 'zhCN' },
      { name: 'English', value: 'en' },
    ]
  }),

  getters: {
    localeInfo: function(): ILocale | null {
      const result = this.localeList.find((item: ILocale) => (item.value == this.locale))
      return result ? result : null
    }
  },

  actions: {
    toggleLocale(localeInfo: ILocale) {
      if (localeInfo) {
        this.locale = localeInfo.value
        localStorage.setItem('locale', locale.value)
      }
    }
  }
})



export default useSystemStore